@@ -2,13 +2,13 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
 
-__all__ = ["GeneratorError", "ParseError", "PropertyError", "ValidationError"]
+__all__ = ["ErrorLevel", "GeneratorError", "ParseError", "PropertyError", "ValidationError"]
 
 from pydantic import BaseModel
 
 
 class ErrorLevel(Enum):
-    """ The level of an error """
+    """The level of an error"""
 
     WARNING = "WARNING"  # Client is still generated but missing some pieces
     ERROR = "ERROR"  # Client could not be generated
@@ -16,7 +16,7 @@ class ErrorLevel(Enum):
 
 @dataclass
 class GeneratorError:
-    """ Base data struct containing info on an error that occurred """
+    """Base data struct containing info on an error that occurred"""
 
     detail: Optional[str] = None
     level: ErrorLevel = ErrorLevel.ERROR
@@ -25,7 +25,7 @@ class GeneratorError:
 
 @dataclass
 class ParseError(GeneratorError):
-    """ An error raised when there's a problem parsing an OpenAPI document """
+    """An error raised when there's a problem parsing an OpenAPI document"""
 
     level: ErrorLevel = ErrorLevel.WARNING
     data: Optional[BaseModel] = None
@@ -34,7 +34,7 @@ class ParseError(GeneratorError):
 
 @dataclass
 class PropertyError(ParseError):
-    """ Error raised when there's a problem creating a Property """
+    """Error raised when there's a problem creating a Property"""
 
     header = "Problem creating a Property: "
 
