@@ -5,34 +5,28 @@ from typing import Any, ClassVar, Dict, List, Optional, Set, Type, Union
 import attr
 
 from ... import utils
-from ..reference import Reference
 from .property import Property
+from .schemas import Class
 
 ValueType = Union[str, int]
 
 
 @attr.s(auto_attribs=True, frozen=True)
 class EnumProperty(Property):
-    """ A property that should use an enum """
+    """A property that should use an enum"""
 
     values: Dict[str, ValueType]
-    reference: Reference
+    class_info: Class
     value_type: Type[ValueType]
     default: Optional[Any] = attr.ib()
 
     template: ClassVar[str] = "enum_property.py.jinja"
 
-    def get_type_string(self, no_optional: bool = False) -> str:
-        """ Get a string representation of type that should be used when declaring this property """
+    def get_base_type_string(self, json: bool = False) -> str:
+        return self.class_info.name
 
-        type_string = self.reference.class_name
-        if no_optional:
-            return type_string
-        if self.nullable:
-            type_string = f"Optional[{type_string}]"
-        if not self.required:
-            type_string = f"Union[Unset, {type_string}]"
-        return type_string
+    def get_base_json_type_string(self, json: bool = False) -> str:
+        return self.value_type.__name__
 
     def get_imports(self, *, prefix: str) -> Set[str]:
         """
@@ -43,12 +37,12 @@ class EnumProperty(Property):
             back to the root of the generated client.
         """
         imports = super().get_imports(prefix=prefix)
-        imports.add(f"from {prefix}models.{self.reference.module_name} import {self.reference.class_name}")
+        imports.add(f"from {prefix}models.{self.class_info.module_name} import {self.class_info.name}")
         return imports
 
     @staticmethod
     def values_from_list(values: List[ValueType]) -> Dict[str, ValueType]:
-        """ Convert a list of values into dict of {name: value} """
+        """Convert a list of values into dict of {name: value}"""
         output: Dict[str, ValueType] = {}
 
         for i, value in enumerate(values):
@@ -58,7 +52,7 @@ class EnumProperty(Property):
                 else:
                     output[f"VALUE_{value}"] = value
                 continue
-            if value[0].isalpha():
+            if value and value[0].isalpha():
                 key = value.upper()
             else:
                 key = f"VALUE_{i}"
