@@ -25,6 +25,7 @@ class ModelProperty(Property):
 
     template: ClassVar[str] = "model_property.py.jinja"
     json_is_dict: ClassVar[bool] = True
+    is_multipart_body: bool = False
 
     def get_base_type_string(self, json: bool = False) -> str:
         return self.class_info.name
@@ -209,6 +210,7 @@ def build_model_property(
         required=required,
         name=name,
         additional_properties=additional_properties,
+        python_name=utils.PythonIdentifier(value=name, prefix=config.field_prefix),
     )
     if class_info.name in schemas.classes_by_name:
         error = PropertyError(data=data, detail=f'Attempted to generate duplicate models with name "{class_info.name}"')
